Method: RCGTK::Module::GlobalCollection#first

Defined in:
lib/rcgtk/module.rb

#firstGlobalVariable?

Returns The module’s first global variable if one has been added.

Returns:

  • (GlobalVariable, nil)

    The module’s first global variable if one has been added.



421
422
423
# File 'lib/rcgtk/module.rb', line 421

def first
	if (ptr = Bindings.get_first_global(@module)).null? then nil else GlobalValue.new(ptr) end
end